==> viper_1.0.0.tar.gz: viper/man/bootstrapTtest-methods.Rd <==
\docType{methods}
\name{bootstrapTtest}
\alias{bootstrapTtest}
\alias{bootstrapTtest,ExpressionSet-method}
\alias{bootstrapTtest,matrix-method}
\title{Bootstrapped signature by t-test}
\usage{
\S4method{bootstrapTtest}{matrix}(x, y, per = 100, seed=1, verbose = TRUE)
\S4method{bootstrapTtest}{ExpressionSet}(x, pheno, group1, group2, per = 100, seed = 1, verbose = TRUE)
}
\arguments{
  \item{x}{Matrix containing the test dataset}

  \item{y}{Matrix containing the reference dataset}

  \item{per}{Integer indicating the number of permutations}

  \item{seed}{Integer indicating the seed for the
  permutations, 0 for disable it #'}

  \item{verbose}{Logical, whether progression messages
  should be printed in the terminal}

  \item{pheno}{Character string indicating the phenotype
  data to use}

  \item{group1}{Vector of character strings indicating the
  category from phenotype \code{pheno} to use as test
  group}

  \item{group2}{Vector of character strings indicating the
  category from phenotype \code{pheno} to use as control
  group}
}
\value{
  Matrix of z-scores with genes in rows and permutations in
  columns
}
\description{
  This function generates a bootstrapped signature matrix
  by t-test
}
\examples{
data(bcellViper, package="bcellViper")
d1 <- exprs(dset)
sig <- bootstrapTtest(d1[, 1:10], d1[, 11:20], per=100)
dim(sig)
plot(density(sig[1907, ]))
data(bcellViper, package="bcellViper")
sig <- bootstrapTtest(dset, "description", "CB", "N", per=100)
dim(sig)
plot(density(sig[1907, ]))
}
\seealso{
  \code{\link{msviper}}
}

==> viper_1.2.0.tar.gz: viper/man/bootstrapTtest-methods.Rd <==
\docType{methods}
\name{bootstrapTtest}
\alias{bootstrapTtest}
\alias{bootstrapTtest,ExpressionSet-method}
\alias{bootstrapTtest,matrix-method}
\title{Bootstrapped signature by t-test}
\usage{
bootstrapTtest(x, ...)

\S4method{bootstrapTtest}{matrix}(x, y, per = 100, seed = 1,
  verbose = TRUE)

\S4method{bootstrapTtest}{ExpressionSet}(x, pheno, group1, group2, per = 100,
  seed = 1, verbose = TRUE)
}
\arguments{
  \item{x}{Matrix containing the test dataset}

  \item{y}{Matrix containing the reference dataset}

  \item{per}{Integer indicating the number of permutations}

  \item{seed}{Integer indicating the seed for the
  permutations, 0 for disable it}

  \item{verbose}{Logical whether progress should be
  reported}

  \item{...}{Additional parameters added to keep
  compatibility}

  \item{pheno}{Character string indicating the phenotype
  data to use}

  \item{group1}{Vector of character strings indicating the
  category from phenotype \code{pheno} to use as test
  group}

  \item{group2}{Vector of character strings indicating the
  category from phenotype \code{pheno} to use as control
  group}
}
\value{
Matrix of z-scores with genes in rows and permutations in
columns
}
\description{
This function generates a bootstrapped signature matrix by
t-test
}
\examples{
data(bcellViper, package="bcellViper")
d1 <- exprs(dset)
sig <- bootstrapTtest(d1[, 1:10], d1[, 11:20], per=100)
dim(sig)
plot(density(sig[1907, ]))
data(bcellViper, package="bcellViper")
sig <- bootstrapTtest(dset, "description", "CB", "N", per=100)
dim(sig)
plot(density(sig[1907, ]))
}
\seealso{
\code{\link{msviper}}
}
